/***************************************************************************
 * Copyright 2012 Kieker Project (http://kieker-monitoring.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.beans.session;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.ManagedProperty;
import javax.faces.bean.SessionScoped;

import kieker.webgui.beans.application.GlobalPropertiesBean;

/**
 * This bean contains information about the user of this session (like user name and authorization). It provides method to log into the application.<br>
 * This class is a JSF managed bean with session scope. This means also that it is possible to login the same user multiple times.
 * 
 * @author Nils Christian Ehmke
 */
@ManagedBean
@SessionScoped
public final class UserBean {

	private String userName;
	private String password;

	@ManagedProperty(value = "#{globalPropertiesBean}")
	private GlobalPropertiesBean globalPropertiesBean;

	/**
	 * Default constructor. <b>Do not use this constructor. This bean is JSF managed.</b>
	 */
	public UserBean() {
		this.userName = "Guest";
	}

	/**
	 * Returns the name of the user of the current session.
	 * 
	 * @return The user name.
	 */
	public String getUserName() {
		return this.userName;
	}

	/**
	 * Sets the new user name of the current session.
	 * 
	 * @param name
	 *            The new user name.
	 */
	public void setUserName(final String name) {
		this.userName = name;
	}

	/**
	 * Delivers the stored password.
	 * 
	 * @return The password.
	 */
	public String getPassword() {
		return this.password;
	}

	/**
	 * Sets the password which should be stored in this bean.
	 * 
	 * @param password
	 *            The new value for the password.
	 */
	public void setPassword(final String password) {
		this.password = password;
	}

	/**
	 * Tries to login. If this has been successful the page of the project overview will be returned.
	 * 
	 * @return The new page.
	 */
	public String login() {
		if (this.globalPropertiesBean != null) {
			return this.globalPropertiesBean.getProjectOverviewPage();
		} else {
			return "";
		}
	}

	/**
	 * The getter for the property {@link UserBean#globalPropertiesBean}.
	 * 
	 * @return The current value of the property.
	 */
	public GlobalPropertiesBean getGlobalPropertiesBean() {
		return this.globalPropertiesBean;
	}

	/**
	 * The setter for the property {@link UserBean#globalPropertiesBean}.
	 * 
	 * @param globalPropertiesBean
	 *            The new value of the property.
	 */
	public void setGlobalPropertiesBean(final GlobalPropertiesBean globalPropertiesBean) {
		this.globalPropertiesBean = globalPropertiesBean;
	}
}
